Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/lc709203f_simpletest.py
    :caption: examples/lc709203f_simpletest.py
    :linenos:

Thermistor test
---------------

Example showing the use of thermistors over I2C

.. literalinclude:: ../examples/lc709203f_thermistortest.py
    :caption: examples/lc709203f_thermistortest.py
    :linenos:
